==> symfony_6.4.21+dfsg.orig.tar.xz: symfony-6.4.21/src/Symfony/Component/Intl/Resources/data/timezones/hi_Latn.php <==
<?php

return [
    'Names' => [
        'Africa/Asmera' => 'पूर्वी अफ़्रीका समय (Asmera)',
        'Africa/Porto-Novo' => 'पश्चिम अफ़्रीका समय (Porto Novo)',
        'Africa/Sao_Tome' => 'ग्रीनविच मीन टाइम (Sao Tome)',
        'America/Asuncion' => 'पैराग्वे समय (Asuncion)',
        'America/Bahia_Banderas' => 'North America Central Time (Bahia Banderas)',
        'America/Belize' => 'North America Central Time (बेलीज़)',
        'America/Blanc-Sablon' => 'अटलांटिक समय (Blanc Sablon)',
        'America/Boise' => 'North America Mountain Time (बॉइसी)',
        'America/Cambridge_Bay' => 'North America Mountain Time (कैम्ब्रिज खाड़ी)',
        'America/Cancun' => 'North America Eastern Time (Cancun)',
        'America/Cayman' => 'North America Eastern Time (कैमेन)',
        'America/Chicago' => 'North America Central Time (शिकागो)',
        'America/Chihuahua' => 'North America Central Time (चिहुआहुआ)',
        'America/Ciudad_Juarez' => 'North America Mountain Time (Ciudad Juarez)',
        'America/Coral_Harbour' => 'North America Eastern Time (Coral Harbour)',
        'America/Costa_Rica' => 'North America Central Time (कोस्टा रिका)',
        'America/Creston' => 'North America Mountain Time (क्रेस्टन)',
        'America/Curacao' => 'अटलांटिक समय (Curacao)',
        'America/Dawson_Creek' => 'North America Mountain Time (डॉसन क्रीक)',
        'America/Denver' => 'North America Mountain Time (डेनवर)',
        'America/Detroit' => 'North America Eastern Time (डेट्रॉयट)',
        'America/Edmonton' => 'North America Mountain Time (एडमंटन)',
        'America/El_Salvador' => 'North America Central Time (अल सल्वाडोर)',
        'America/Fort_Nelson' => 'North America Mountain Time (फ़ोर्ट नेल्सन)',
        'America/Grand_Turk' => 'North America Eastern Time (ग्रांड टर्क)',
        'America/Guatemala' => 'North America Central Time (ग्वाटेमाला)',
        'America/Indiana/Knox' => 'North America Central Time (नौक्स, इंडियाना)',
        'America/Indiana/Marengo' => 'North America Eastern Time (मारेंगो, इंडियाना)',
        'America/Indiana/Petersburg' => 'North America Eastern Time (पीटर्सबर्ग, इंडियाना)',
        'America/Indiana/Tell_City' => 'North America Central Time (टेल सिटी, इंडियाना)',
        'America/Indiana/Vevay' => 'North America Eastern Time (वेवे, इंडियाना)',
        'America/Indiana/Vincennes' => 'North America Eastern Time (विंसेनेस, इंडियाना)',
        'America/Indiana/Winamac' => 'North America Eastern Time (विनामेक, इंडियाना)',
        'America/Indianapolis' => 'North America Eastern Time (इंडियानापोलिस)',
        'America/Inuvik' => 'North America Mountain Time (इनूविक)',
        'America/Iqaluit' => 'North America Eastern Time (इकालुईट)',
        'America/Jamaica' => 'North America Eastern Time (जमैका)',
        'America/Kentucky/Monticello' => 'North America Eastern Time (मोंटीसेलो, केंटकी)',
        'America/Los_Angeles' => 'North America Pacific Time (लॉस एंजिल्स)',
        'America/Louisville' => 'North America Eastern Time (लुइसविले)',
        'America/Managua' => 'North America Central Time (मानागुआ)',
        'America/Matamoros' => 'North America Central Time (माटामोरोस)',
        'America/Menominee' => 'North America Central Time (मेनोमिनी)',
        'America/Merida' => 'North America Central Time (Merida)',
        'America/Mexico_City' => 'North America Central Time (मेक्सिको सिटी)',
        'America/Miquelon' => 'St. Pierre & Miquelon Time (मिकेलॉन)',
        'America/Monterrey' => 'North America Central Time (मोंटेरेरी)',
        'America/Nassau' => 'North America Eastern Time (नासाउ)',
        'America/New_York' => 'North America Eastern Time (न्यूयॉर्क)',
        'America/North_Dakota/Beulah' => 'North America Central Time (ब्यूला, उत्तरी डकोटा)',
        'America/North_Dakota/Center' => 'North America Central Time (मध्य, उत्तरी दाकोता)',
        'America/North_Dakota/New_Salem' => 'North America Central Time (न्यू सालेम, उत्तरी डकोटा)',
        'America/Ojinaga' => 'North America Central Time (ओखाजीनागा)',
        'America/Panama' => 'North America Eastern Time (पनामा)',
        'America/Phoenix' => 'North America Mountain Time (फ़ीनिक्स)',
        'America/Port-au-Prince' => 'North America Eastern Time (पोर्ट-ऑ-प्रिंस)',
        'America/Rankin_Inlet' => 'North America Central Time (रेंकिन इनलेट)',
        'America/Regina' => 'North America Central Time (रेजिना)',
        'America/Resolute' => 'North America Central Time (रिसोल्यूट)',
        'America/St_Barthelemy' => 'अटलांटिक समय (St Barthelemy)',
        'America/Swift_Current' => 'North America Central Time (स्विफ़्ट करंट)',
        'America/Tegucigalpa' => 'North America Central Time (टेगुसिगल्पा)',
        'America/Tijuana' => 'North America Pacific Time (तिजुआना)',
        'America/Toronto' => 'North America Eastern Time (टोरंटो)',
        'America/Vancouver' => 'North America Pacific Time (वैंकूवर)',
        'America/Winnipeg' => 'North America Central Time (विनीपेग)',
        'Antarctica/DumontDUrville' => 'ड्यूमोंट डी अर्विले समय (DumontDUrville)',
        'Asia/Aqtau' => 'कज़ाखस्तान समय (Aqtau)',
        'Asia/Macau' => 'चीन समय (Macau)',
        'Asia/Qostanay' => 'कज़ाखस्तान समय (Qostanay)',
        'Asia/Saigon' => 'इंडोचाइना समय (Saigon)',
        'Atlantic/Faeroe' => 'पश्चिमी यूरोपीय समय (Faeroe)',
        'Europe/Istanbul' => 'Turkiye समय (इस्तांबुल)',
        'Indian/Reunion' => 'Reunion Time',
        'Pacific/Honolulu' => 'हवाई–आल्यूशन समय (Honolulu)',
        'Pacific/Ponape' => 'पोनापे समय (Ponape)',
        'Pacific/Truk' => 'चुक समय (Truk)',
    ],
    'Meta' => [],
];

==> symfony_6.4.25+dfsg.orig.tar.xz: symfony-6.4.25/src/Symfony/Component/Intl/Resources/data/timezones/hi_Latn.php <==
<?php

return [
    'Names' => [
        'Africa/Asmera' => 'पूर्वी अफ़्रीका समय (Asmera)',
        'Africa/Asmara' => 'पूर्वी अफ़्रीका समय (Asmera)',
        'Africa/Porto-Novo' => 'पश्चिम अफ़्रीका समय (Porto Novo)',
        'Africa/Sao_Tome' => 'ग्रीनविच मीन टाइम (Sao Tome)',
        'America/Asuncion' => 'पैराग्वे समय (Asuncion)',
        'America/Bahia_Banderas' => 'North America Central Time (Bahia Banderas)',
        'America/Belize' => 'North America Central Time (बेलीज़)',
        'America/Blanc-Sablon' => 'अटलांटिक समय (Blanc Sablon)',
        'America/Boise' => 'North America Mountain Time (बॉइसी)',
        'America/Cambridge_Bay' => 'North America Mountain Time (कैम्ब्रिज खाड़ी)',
        'America/Cancun' => 'North America Eastern Time (Cancun)',
        'America/Cayman' => 'North America Eastern Time (कैमेन)',
        'America/Chicago' => 'North America Central Time (शिकागो)',
        'America/Chihuahua' => 'North America Central Time (चिहुआहुआ)',
        'America/Ciudad_Juarez' => 'North America Mountain Time (Ciudad Juarez)',
        'America/Coral_Harbour' => 'North America Eastern Time (Coral Harbour)',
        'America/Atikokan' => 'North America Eastern Time (Coral Harbour)',
        'America/Costa_Rica' => 'North America Central Time (कोस्टा रिका)',
        'America/Creston' => 'North America Mountain Time (क्रेस्टन)',
        'America/Curacao' => 'अटलांटिक समय (Curacao)',
        'America/Dawson_Creek' => 'North America Mountain Time (डॉसन क्रीक)',
        'America/Denver' => 'North America Mountain Time (डेनवर)',
        'America/Detroit' => 'North America Eastern Time (डेट्रॉयट)',
        'America/Edmonton' => 'North America Mountain Time (एडमंटन)',
        'America/El_Salvador' => 'North America Central Time (अल सल्वाडोर)',
        'America/Fort_Nelson' => 'North America Mountain Time (फ़ोर्ट नेल्सन)',
        'America/Grand_Turk' => 'North America Eastern Time (ग्रांड टर्क)',
        'America/Guatemala' => 'North America Central Time (ग्वाटेमाला)',
        'America/Indiana/Knox' => 'North America Central Time (नौक्स, इंडियाना)',
        'America/Indiana/Marengo' => 'North America Eastern Time (मारेंगो, इंडियाना)',
        'America/Indiana/Petersburg' => 'North America Eastern Time (पीटर्सबर्ग, इंडियाना)',
        'America/Indiana/Tell_City' => 'North America Central Time (टेल सिटी, इंडियाना)',
        'America/Indiana/Vevay' => 'North America Eastern Time (वेवे, इंडियाना)',
        'America/Indiana/Vincennes' => 'North America Eastern Time (विंसेनेस, इंडियाना)',
        'America/Indiana/Winamac' => 'North America Eastern Time (विनामेक, इंडियाना)',
        'America/Indianapolis' => 'North America Eastern Time (इंडियानापोलिस)',
        'America/Indiana/Indianapolis' => 'North America Eastern Time (इंडियानापोलिस)',
        'America/Inuvik' => 'North America Mountain Time (इनूविक)',
        'America/Iqaluit' => 'North America Eastern Time (इकालुईट)',
        'America/Jamaica' => 'North America Eastern Time (जमैका)',
        'America/Kentucky/Monticello' => 'North America Eastern Time (मोंटीसेलो, केंटकी)',
        'America/Los_Angeles' => 'North America Pacific Time (लॉस एंजिल्स)',
        'America/Louisville' => 'North America Eastern Time (लुइसविले)',
        'America/Kentucky/Louisville' => 'North America Eastern Time (लुइसविले)',
        'America/Managua' => 'North America Central Time (मानागुआ)',
        'America/Matamoros' => 'North America Central Time (माटामोरोस)',
        'America/Menominee' => 'North America Central Time (मेनोमिनी)',
        'America/Merida' => 'North America Central Time (Merida)',
        'America/Mexico_City' => 'North America Central Time (मेक्सिको सिटी)',
        'America/Miquelon' => 'St. Pierre & Miquelon Time (मिकेलॉन)',
        'America/Monterrey' => 'North America Central Time (मोंटेरेरी)',
        'America/Nassau' => 'North America Eastern Time (नासाउ)',
        'America/New_York' => 'North America Eastern Time (न्यूयॉर्क)',
        'America/North_Dakota/Beulah' => 'North America Central Time (ब्यूला, उत्तरी डकोटा)',
        'America/North_Dakota/Center' => 'North America Central Time (मध्य, उत्तरी दाकोता)',
        'America/North_Dakota/New_Salem' => 'North America Central Time (न्यू सालेम, उत्तरी डकोटा)',
        'America/Ojinaga' => 'North America Central Time (ओखाजीनागा)',
        'America/Panama' => 'North America Eastern Time (पनामा)',
        'America/Phoenix' => 'North America Mountain Time (फ़ीनिक्स)',
        'America/Port-au-Prince' => 'North America Eastern Time (पोर्ट-ऑ-प्रिंस)',
        'America/Rankin_Inlet' => 'North America Central Time (रेंकिन इनलेट)',
        'America/Regina' => 'North America Central Time (रेजिना)',
        'America/Resolute' => 'North America Central Time (रिसोल्यूट)',
        'America/St_Barthelemy' => 'अटलांटिक समय (St Barthelemy)',
        'America/Swift_Current' => 'North America Central Time (स्विफ़्ट करंट)',
        'America/Tegucigalpa' => 'North America Central Time (टेगुसिगल्पा)',
        'America/Tijuana' => 'North America Pacific Time (तिजुआना)',
        'America/Toronto' => 'North America Eastern Time (टोरंटो)',
        'America/Vancouver' => 'North America Pacific Time (वैंकूवर)',
        'America/Winnipeg' => 'North America Central Time (विनीपेग)',
        'Antarctica/DumontDUrville' => 'ड्यूमोंट डी अर्विले समय (DumontDUrville)',
        'Asia/Aqtau' => 'कज़ाखस्तान समय (Aqtau)',
        'Asia/Macau' => 'चीन समय (Macau)',
        'Asia/Qostanay' => 'कज़ाखस्तान समय (Qostanay)',
        'Asia/Saigon' => 'इंडोचाइना समय (Saigon)',
        'Asia/Ho_Chi_Minh' => 'इंडोचाइना समय (Saigon)',
        'Atlantic/Faeroe' => 'पश्चिमी यूरोपीय समय (Faeroe)',
        'Atlantic/Faroe' => 'पश्चिमी यूरोपीय समय (Faeroe)',
        'Europe/Istanbul' => 'Turkiye समय (इस्तांबुल)',
        'Indian/Reunion' => 'Reunion Time',
        'Pacific/Honolulu' => 'हवाई–आल्यूशन समय (Honolulu)',
        'Pacific/Ponape' => 'पोनापे समय (Ponape)',
        'Pacific/Pohnpei' => 'पोनापे समय (Ponape)',
        'Pacific/Truk' => 'चुक समय (Truk)',
        'Pacific/Chuuk' => 'चुक समय (Truk)',
    ],
    'Meta' => [],
];
